# Supplementary material

This is the supplementary material for *Stochastic Fine-grained Labeling of Multi-state Sign Glosses for Continuous Sign Language Recognition*. The supplementary material aims to provide more quantitative results of our framework for different samples. The directory structure of this supplementary material is list as following:

```
.
├── animation        <- spatial feature visualization (first 150 samples on dev set)
├── attention        <- self-attention map (first 150 samples on dev set)
├── posteriors       <- ctc posteriors (first 150 samples on dev set)
├── hypothesis       <- the hypothesis produced by our best model, -lm for where language model is used
├── README.md       
├── count.csv        <- the state counts of the ResNet18 model
└── count.svg        <- the state counts of the ResNet18 model
```

## 1. Spatial feature visualization

![](animation/00000.gif)

In the animation, the reference in the title shows the ground truth labels, while the hypothesis is generated with beam size 10 and state transition limitation, and argmax is the argmax of the posterior at each frame. The left sub-figure shows the T-SNE projection of the spatial feature for each frame. The right sub-figure shows the activation map, which a maximal pool along the channels of the $7\times7$ ResNet18 feature maps; the reddish part has more activation. The label on the upper right corner of the right sub-figure shows the most probable state class (including blank) of the current frame.

As shown in the animation, the activation of the CNN focuses on the mouse and the right hand more, and in some frames, the left hand is also activated. This is consistent with the fact that the right hand normally carries more information for signing glosses.

## 2. Self-attention map

The attention map is provided in the `attention' folder, where $l_i,h_j$ in the subtitle mean layer $i$ head $j$. Consider the following example:

![](./attention/00000.svg)

For the majority of the attention maps, the attentive pattern is a band with a certain width along the diagonal, indicating the particular frame is attended to only its neighborhood frames. While some other heads like $l_1,h_1$ looks for future frames and $l_0, h_2$ looks for the past frames, which shows the network utilizing contextual information for better prediction.

## 3. Posteriors figure

The figures show posteriors of the states of the target glosses given different frames. We plot the maximal posterior of the current frame, in which only the posteriors of the ground truth words are considered during the plotting. 

![](./posterior/00000.svg)

For example, the above figure shows the sentence "ICH OSTERN WETTER ZUFRIEDEN MITTAG TEMPERATUR SUED WARM \<unk\> NICHT", where \<unk\> is an OOV word. The gloss ICH has two peaks in two states, but the network seems not very confident on both peaks. While for the gloss like WARM, the network gives high posterior for both peaks. Some states have posterior 0 (e.g. ICH-5) as the fine-grained labeling did not use the 5-th state to label the gloss.

## 4. Distribution over the state counts

![](./count.svg)

The figure shows the distribution over the state counts provided by the ResNet18 model trained with max count being $5$, which achieves 26.2/26.8% WER on the dev and test set respectively. From the figure we can find, for this model, the state counts for most of the glosses are 2, while some other glosses require 4 states. This is consistent with our results in Figure 5 in the paper, as if a fixed number of states is adopted for all the glosses, setting the number to 2 gives the best results 26.5%/27.2% WER on the dev set and test set respectively. The network prefers 4 states for some glosses. We assume this difference leads to performance improvement.
